@@ -18,12 +18,13 @@ Released under the MIT License; see LICENSE file for details.
 * v1.3, allow non-numeric parameters, May 2021, Matthias Cuntz
 * v1.3.1, more general treatment of right-hand side in sub_params_names,
   May 2021, Matthias Cuntz
-* v1.3.2, protect saved groups in replacement pattern, May 2021, Matthias Cuntz
+* v1.3.2, protect saved groups in replacement pattern in std_io, May 2021, Matthias Cuntz
 * v1.3.3, deleted trailing print statement, May 2021, Matthias Cuntz
-* v1.3.4, escape backslash in names, May 2021, Matthias Cuntz
+* v1.3.4, escape backslash in params in std_io, May 2021, Matthias Cuntz
+* v1.3.5, escape backslash also in sub_params_ja, May 2021, Matthias Cuntz
 
 .. moduleauthor:: Matthias Cuntz
 """
 
 __author__  = "Matthias Cuntz"
-__version__ = "1.3.4"
+__version__ = "1.3.5"
